PCB Environment: BaseROP Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
BaseROP Class Referenceabstract
Inheritance diagram for BaseROP:

## Public Member Functions
void | reserve (uint N)
virtual void | writeRangeZYX (uint Z0, uint Z1, uint Y0, uint Y1, uint X0, uint X1)=0
void | writeRangeZX (uint Z0, uint Z1, uint Y, uint X0, uint X1)
void | writeRangeZY (uint Z0, uint Z1, uint Y0, uint Y1, uint X)
void | writeRangeYX (uint Z, uint Y0, uint Y1, uint X0, uint X1)
void | writeRangeY (uint Z, uint Y0, uint Y1, uint X)
void | writeRangeX (uint Z, uint Y, uint X0, uint X1)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Rasterizer.hpp